############
kafkaconnect
############

|Build| |Docker|

A Python client for managing connectors using the `Kafka Connect API <https://docs.confluent.io/current/connect/references/restapi.html>`_.

See `the docs <https://kafka-connect-manager.lsst.io>`_ for more information.


.. |Build| image:: https://github.com/lsst-sqre/kafka-connect-manager/workflows/CI/badge.svg
  :alt: GitHub Actions
  :scale: 100%
  :target: https://github.com/lsst-sqre/kafka-connect-manager/actions

.. |Docker| image:: https://img.shields.io/docker/v/lsstsqre/kafkaconnect?sort=date
  :alt: Docker Hub repository
  :scale: 100%
  :target: https://hub.docker.com/repository/docker/lsstsqre/kafkaconnect
